@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "turepo" "0.2.0"
+(define-package "turepo" "20260106.1210"
   "Open git repository in browser."
   '((emacs "28.1"))
   :url "https://github.com/swarnimcodes/turepo"
